==> haskell-insert-ordered-containers-0.2.1.0-9-i686.pkg.tar.xz: usr/share/haskell/register/haskell-insert-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: insert-ordered-containers
version: 0.2.1.0
id: insert-ordered-containers-0.2.1.0-BwC5uTf2HL1KqUgqa7bZfB
key: insert-ordered-containers-0.2.1.0-BwC5uTf2HL1KqUgqa7bZfB
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/insert-ordered-containers#readme
synopsis: Associative containers retating insertion order for traversals.
description:
    Associative containers retating insertion order for traversals.
category: Web
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
exposed-modules:
    Data.HashMap.Strict.InsOrd
abi: aaa4df1c2e7d5a3a45c60296ff9fcafe
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/insert-ordered-containers-0.2.1.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/insert-ordered-containers-0.2.1.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/insert-ordered-containers-0.2.1.0
hs-libraries: HSinsert-ordered-containers-0.2.1.0-BwC5uTf2HL1KqUgqa7bZfB
depends:
    aeson-1.1.2.0-KSzOWeOw6cI7ymVovOXtxy base-4.9.0.0
    base-compat-0.9.3-DrSgCcixJxxKb6RsGgHyiF
    hashable-1.2.6.0-CKFo6Z8S7bXH0jokyKXcu0
    lens-4.15.2-AMe59JL4knEI5ISbnCA6nW
    semigroupoids-5.2-4ZQ3kF1yWRr609NjdCdW7C
    semigroups-0.18.3-8OeihxGDuPl3I5Jsa4Tvoj
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v transformers-0.5.2.0
    unordered-containers-0.2.8.0-Njz6QHP7Gk5G9PhT6D28J
haddock-interfaces: /usr/share/doc/haskell-insert-ordered-containers/html/insert-ordered-containers.haddock
haddock-html: /usr/share/doc/haskell-insert-ordered-containers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-insert-ordered-containers-0.2.1.0-13-i686.pkg.tar.xz: usr/share/haskell/register/haskell-insert-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: insert-ordered-containers
version: 0.2.1.0
id: insert-ordered-containers-0.2.1.0-GRO7mpG1A76LRio88Ila6X
key: insert-ordered-containers-0.2.1.0-GRO7mpG1A76LRio88Ila6X
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/insert-ordered-containers#readme
synopsis: Associative containers retating insertion order for traversals.
description:
    Associative containers retating insertion order for traversals.
category: Web
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
exposed-modules:
    Data.HashMap.Strict.InsOrd
abi: fea63ae34b73a1902a676494d1c73790
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/insert-ordered-containers-0.2.1.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/insert-ordered-containers-0.2.1.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/insert-ordered-containers-0.2.1.0
hs-libraries: HSinsert-ordered-containers-0.2.1.0-GRO7mpG1A76LRio88Ila6X
depends:
    aeson-1.1.2.0-6MVvUcgiXyL5LInpwFqRIH base-4.9.0.0
    base-compat-0.9.3-DrSgCcixJxxKb6RsGgHyiF
    hashable-1.2.6.0-CKFo6Z8S7bXH0jokyKXcu0
    lens-4.15.3-3lNPFRGRdq2HBjBjvOKis5
    semigroupoids-5.2-4ZQ3kF1yWRr609NjdCdW7C
    semigroups-0.18.3-8OeihxGDuPl3I5Jsa4Tvoj
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v transformers-0.5.2.0
    unordered-containers-0.2.8.0-Njz6QHP7Gk5G9PhT6D28J
haddock-interfaces: /usr/share/doc/haskell-insert-ordered-containers/html/insert-ordered-containers.haddock
haddock-html: /usr/share/doc/haskell-insert-ordered-containers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
